@@ -6,6 +6,8 @@
 import configparser
 import logging.config
 
+from mobio.libs.logging import MobioLogging
+
 from mobio.libs.Singleton import Singleton
 from mobio.sdks.base.configs import ApplicationConfig
 
@@ -28,11 +30,11 @@ class SystemConfig:
             try:
                 local_dic[option] = self.config.get(section, option)
                 if local_dic[option] == -1:
-                    print("INFO:MOBIO:SystemConfig.get_section_map():skip: %s" % option)
+                    MobioLogging().info('system_config::get_section_map():skip: %s' % option)
             except Exception as e:
-                print("ERROR:MOBIO::SystemConfig.get_section_map():section: %s" % section)
-                print("ERROR:MOBIO::SystemConfig.get_section_map():option: %s" % option)
-                print("ERROR:MOBIO::SystemConfig.get_section_map():error: %s" % e)
+                MobioLogging().error('system_config::get_section_map():section: %s' % section)
+                MobioLogging().error('system_config::get_section_map():option: %s' % option)
+                MobioLogging().error('system_config::get_section_map():error: %s' % e)
                 local_dic[option] = None
         self._sections[section] = local_dic
         return local_dic
